Account database helpers.
Static glibc binaries cannot safely use NSS-backed account lookups such as
getpwuid_r(3). In that build mode we read the local account files
directly; other builds keep the usual libc/NSS behavior.
Account database helpers.
Static glibc binaries cannot safely use NSS-backed account lookups such as
getpwuid_r(3). In that build mode we read the local account files
directly; other builds keep the usual libc/NSS behavior.