Module config

Module config 

Structs

Config
DebuggerConfig
LogModeConfig
ModifierConfig
PtraceConfig
TimestampConfig
TracexecProjectDirs
Wrapper around ProjectDirs that supports overriding directories (e.g. when running elevated via sudo, to use the original user’s dirs).
TuiModeConfig

Enums

ColorLevel
ConfigLoadError
EnvDisplay
ExitHandling
FileDescriptorDisplay

Functions

project_directory
set_project_dir_overrides
Set overrides for the project directories. Must be called before any call to project_directory(). Used by the elevated process to point at the original user’s config/data directories.