pub struct PtyFd(pub FileDescriptor);Tuple Fields
0: FileDescriptorMethods from Deref<Target = FileDescriptor>
Sourcepub fn try_clone(&self) -> Result<FileDescriptor, Error>
pub fn try_clone(&self) -> Result<FileDescriptor, Error>
Attempt to duplicate the underlying handle and return a
FileDescriptor wrapped around the duplicate. Since the duplication
requires kernel resources that may not be available, this is a
potentially fallible operation.
The returned handle has a separate lifetime from the source, but
references the same object at the kernel level.
Sourcepub fn as_stdio(&self) -> Result<Stdio, Error>
pub fn as_stdio(&self) -> Result<Stdio, Error>
A convenience method for creating a std::process::Stdio object
to be used for eg: redirecting the stdio streams of a child
process. The Stdio is created using a duplicated handle so
that the source handle remains alive.
Sourcepub fn as_file(&self) -> Result<File, Error>
pub fn as_file(&self) -> Result<File, Error>
A convenience method for creating a std::fs::File object.
The File is created using a duplicated handle so
that the source handle remains alive.
Sourcepub fn set_non_blocking(&mut self, non_blocking: bool) -> Result<(), Error>
pub fn set_non_blocking(&mut self, non_blocking: bool) -> Result<(), Error>
Attempt to change the non-blocking IO mode of the file descriptor. Not all kinds of file descriptor can be placed in non-blocking mode on all systems, and some file descriptors will claim to be in non-blocking mode but it will have no effect. File descriptors based on sockets are the most portable type that can be successfully made non-blocking.