PtySystem

Trait PtySystem 

pub trait PtySystem {
    // Required method
    fn openpty(&self, size: PtySize) -> Result<PtyPair>;
}
The PtySystem trait allows an application to work with multiple possible Pty implementations at runtime. This is important on Windows systems which have a variety of implementations.

Required Methods

fn openpty(&self, size: PtySize) -> Result<PtyPair>

Create a new Pty instance with the window size set to the specified dimensions. Returns a (master, slave) Pty pair. The master side is used to drive the slave side.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors