Structs
- Config
- Debugger
Config - LogMode
Config - Modifier
Config - Ptrace
Config - Timestamp
Config - Tracexec
Project Dirs - Wrapper around
ProjectDirsthat supports overriding directories (e.g. when running elevated via sudo, to use the original user’s dirs). - TuiMode
Config
Enums
Functions
- project_
directory - set_
project_ dir_ overrides - Set overrides for the project directories. Must be called before any call to
project_directory(). Used by the elevated process to point at the original user’s config/data directories.