pub struct ThemeSpec {Show 100 fields
pub inactive_border: Option<StyleSpec>,
pub active_border: Option<StyleSpec>,
pub popup_border: Option<StyleSpec>,
pub app_title: Option<StyleSpec>,
pub help_popup: Option<StyleSpec>,
pub inline_timestamp: Option<StyleSpec>,
pub cli_flag: Option<StyleSpec>,
pub help_key: Option<StyleSpec>,
pub help_desc: Option<StyleSpec>,
pub fancy_help_desc: Option<StyleSpec>,
pub pid_success: Option<StyleSpec>,
pub pid_failure: Option<StyleSpec>,
pub pid_enoent: Option<StyleSpec>,
pub pid_in_msg: Option<StyleSpec>,
pub comm: Option<StyleSpec>,
pub tracer_info: Option<StyleSpec>,
pub tracer_warning: Option<StyleSpec>,
pub tracer_error: Option<StyleSpec>,
pub new_child_pid: Option<StyleSpec>,
pub tracer_event: Option<StyleSpec>,
pub inline_tracer_error: Option<StyleSpec>,
pub partial_ok: Option<StyleSpec>,
pub filename: Option<StyleSpec>,
pub modified_fd_in_cmdline: Option<StyleSpec>,
pub removed_fd_in_cmdline: Option<StyleSpec>,
pub cloexec_fd_in_cmdline: Option<StyleSpec>,
pub added_fd_in_cmdline: Option<StyleSpec>,
pub arg0: Option<StyleSpec>,
pub cwd: Option<StyleSpec>,
pub deleted_env_var: Option<StyleSpec>,
pub modified_env_var: Option<StyleSpec>,
pub added_env_var: Option<StyleSpec>,
pub argv: Option<StyleSpec>,
pub search_match: Option<StyleSpec>,
pub query_no_match: Option<StyleSpec>,
pub query_match_current_no: Option<StyleSpec>,
pub query_match_total_cnt: Option<StyleSpec>,
pub empty_field: Option<StyleSpec>,
pub uid_gid_name: Option<StyleSpec>,
pub uid_gid_value: Option<StyleSpec>,
pub exec_result_success: Option<StyleSpec>,
pub exec_result_failure: Option<StyleSpec>,
pub value_unknown: Option<StyleSpec>,
pub fd_closed: Option<StyleSpec>,
pub plus_sign: Option<StyleSpec>,
pub minus_sign: Option<StyleSpec>,
pub equal_sign: Option<StyleSpec>,
pub added_env_key: Option<StyleSpec>,
pub added_env_val: Option<StyleSpec>,
pub removed_env_key: Option<StyleSpec>,
pub removed_env_val: Option<StyleSpec>,
pub unchanged_env_key: Option<StyleSpec>,
pub unchanged_env_val: Option<StyleSpec>,
pub fd_label: Option<StyleSpec>,
pub fd_number_label: Option<StyleSpec>,
pub sublabel: Option<StyleSpec>,
pub selected_label: Option<StyleSpec>,
pub label: Option<StyleSpec>,
pub selection_indicator: Option<StyleSpec>,
pub open_flag_cloexec: Option<StyleSpec>,
pub open_flag_access_mode: Option<StyleSpec>,
pub open_flag_creation: Option<StyleSpec>,
pub open_flag_status: Option<StyleSpec>,
pub open_flag_other: Option<StyleSpec>,
pub visual_separator: Option<StyleSpec>,
pub error_popup: Option<StyleSpec>,
pub info_popup: Option<StyleSpec>,
pub active_tab: Option<StyleSpec>,
pub status_process_running: Option<StyleSpec>,
pub status_process_paused: Option<StyleSpec>,
pub status_process_detached: Option<StyleSpec>,
pub status_exec_error: Option<StyleSpec>,
pub status_process_exited_normally: Option<StyleSpec>,
pub status_process_exited_abnormally: Option<StyleSpec>,
pub status_process_killed: Option<StyleSpec>,
pub status_process_terminated: Option<StyleSpec>,
pub status_process_interrupted: Option<StyleSpec>,
pub status_process_segfault: Option<StyleSpec>,
pub status_process_aborted: Option<StyleSpec>,
pub status_process_sigill: Option<StyleSpec>,
pub status_process_signaled: Option<StyleSpec>,
pub status_internal_failure: Option<StyleSpec>,
pub breakpoint_title_selected: Option<StyleSpec>,
pub breakpoint_title: Option<StyleSpec>,
pub breakpoint_pattern_type_label: Option<StyleSpec>,
pub breakpoint_pattern: Option<StyleSpec>,
pub breakpoint_info_label: Option<StyleSpec>,
pub breakpoint_info_label_active: Option<StyleSpec>,
pub breakpoint_info_value: Option<StyleSpec>,
pub hit_entry_pid: Option<StyleSpec>,
pub hit_entry_plain_text: Option<StyleSpec>,
pub hit_entry_breakpoint_stop: Option<StyleSpec>,
pub hit_entry_breakpoint_pattern: Option<StyleSpec>,
pub hit_entry_no_breakpoint_pattern: Option<StyleSpec>,
pub hit_manager_default_command: Option<StyleSpec>,
pub hit_manager_no_default_command: Option<StyleSpec>,
pub backtrace_parent_spawns: Option<SpanSpec>,
pub backtrace_parent_becomes: Option<SpanSpec>,
pub backtrace_parent_unknown: Option<SpanSpec>,
pub extra: HashMap<String, Value>,
}Expand description
Partial theme specification loaded from a TOML file or inline config table. Only explicitly set fields override the built-in theme.
Fields
inactive_border: Option<StyleSpec>active_border: Option<StyleSpec>popup_border: Option<StyleSpec>app_title: Option<StyleSpec>help_popup: Option<StyleSpec>inline_timestamp: Option<StyleSpec>cli_flag: Option<StyleSpec>help_key: Option<StyleSpec>help_desc: Option<StyleSpec>fancy_help_desc: Option<StyleSpec>pid_success: Option<StyleSpec>pid_failure: Option<StyleSpec>pid_enoent: Option<StyleSpec>pid_in_msg: Option<StyleSpec>comm: Option<StyleSpec>tracer_info: Option<StyleSpec>tracer_warning: Option<StyleSpec>tracer_error: Option<StyleSpec>new_child_pid: Option<StyleSpec>tracer_event: Option<StyleSpec>inline_tracer_error: Option<StyleSpec>partial_ok: Option<StyleSpec>filename: Option<StyleSpec>modified_fd_in_cmdline: Option<StyleSpec>removed_fd_in_cmdline: Option<StyleSpec>cloexec_fd_in_cmdline: Option<StyleSpec>added_fd_in_cmdline: Option<StyleSpec>arg0: Option<StyleSpec>cwd: Option<StyleSpec>deleted_env_var: Option<StyleSpec>modified_env_var: Option<StyleSpec>added_env_var: Option<StyleSpec>argv: Option<StyleSpec>search_match: Option<StyleSpec>query_no_match: Option<StyleSpec>query_match_current_no: Option<StyleSpec>query_match_total_cnt: Option<StyleSpec>empty_field: Option<StyleSpec>uid_gid_name: Option<StyleSpec>uid_gid_value: Option<StyleSpec>exec_result_success: Option<StyleSpec>exec_result_failure: Option<StyleSpec>value_unknown: Option<StyleSpec>fd_closed: Option<StyleSpec>plus_sign: Option<StyleSpec>minus_sign: Option<StyleSpec>equal_sign: Option<StyleSpec>added_env_key: Option<StyleSpec>added_env_val: Option<StyleSpec>removed_env_key: Option<StyleSpec>removed_env_val: Option<StyleSpec>unchanged_env_key: Option<StyleSpec>unchanged_env_val: Option<StyleSpec>fd_label: Option<StyleSpec>fd_number_label: Option<StyleSpec>sublabel: Option<StyleSpec>selected_label: Option<StyleSpec>label: Option<StyleSpec>selection_indicator: Option<StyleSpec>open_flag_cloexec: Option<StyleSpec>open_flag_access_mode: Option<StyleSpec>open_flag_creation: Option<StyleSpec>open_flag_status: Option<StyleSpec>open_flag_other: Option<StyleSpec>visual_separator: Option<StyleSpec>error_popup: Option<StyleSpec>info_popup: Option<StyleSpec>active_tab: Option<StyleSpec>status_process_running: Option<StyleSpec>status_process_paused: Option<StyleSpec>status_process_detached: Option<StyleSpec>status_exec_error: Option<StyleSpec>status_process_exited_normally: Option<StyleSpec>status_process_exited_abnormally: Option<StyleSpec>status_process_killed: Option<StyleSpec>status_process_terminated: Option<StyleSpec>status_process_interrupted: Option<StyleSpec>status_process_segfault: Option<StyleSpec>status_process_aborted: Option<StyleSpec>status_process_sigill: Option<StyleSpec>status_process_signaled: Option<StyleSpec>status_internal_failure: Option<StyleSpec>breakpoint_title_selected: Option<StyleSpec>breakpoint_title: Option<StyleSpec>breakpoint_pattern_type_label: Option<StyleSpec>breakpoint_pattern: Option<StyleSpec>breakpoint_info_label: Option<StyleSpec>breakpoint_info_label_active: Option<StyleSpec>breakpoint_info_value: Option<StyleSpec>hit_entry_pid: Option<StyleSpec>hit_entry_plain_text: Option<StyleSpec>hit_entry_breakpoint_stop: Option<StyleSpec>hit_entry_breakpoint_pattern: Option<StyleSpec>hit_entry_no_breakpoint_pattern: Option<StyleSpec>hit_manager_default_command: Option<StyleSpec>hit_manager_no_default_command: Option<StyleSpec>backtrace_parent_spawns: Option<SpanSpec>backtrace_parent_becomes: Option<SpanSpec>backtrace_parent_unknown: Option<SpanSpec>extra: HashMap<String, Value>Collects unrecognised top-level theme keys so the caller can warn about them.
Implementations
Sourceimpl ThemeSpec
impl ThemeSpec
Sourcepub fn warn_unknown_fields(&self, source: &str, section: Option<&str>)
pub fn warn_unknown_fields(&self, source: &str, section: Option<&str>)
Emit tracing::warn! for every unknown field in this spec and in all
nested StyleSpec / SpanSpec values.
source is a human-readable description of where the spec came from
(e.g. a file path or "inline theme config").